@@ -10,10 +10,9 @@ from pyproj.datadir import get_data_dir, get_user_data_dir, set_data_dir
 
 _NETWORK_ENABLED = pyproj.network.is_network_enabled()
 PROJ_LOOSE_VERSION = version.parse(pyproj.__proj_version__)
-PROJ_GTE_81 = PROJ_LOOSE_VERSION >= version.parse("8.1")
-PROJ_GTE_82 = PROJ_LOOSE_VERSION >= version.parse("8.2")
+PROJ_GTE_9 = PROJ_LOOSE_VERSION >= version.parse("9.0.0")
 PROJ_GTE_901 = PROJ_LOOSE_VERSION >= version.parse("9.0.1")
-RGF93toWSG84 = "RGF93 v1 to WGS 84 (1)" if PROJ_GTE_82 else "RGF93 to WGS 84 (1)"
+PROJ_GTE_91 = PROJ_LOOSE_VERSION >= version.parse("9.1")
 
 
 def unset_data_dir():
@@ -66,7 +65,7 @@ def grids_available(*grid_names, check_network=True, check_all=False):
     """
     Check if the grids are available
     """
-    if check_network and os.environ.get("PROJ_NETWORK") == "ON":
+    if check_network and pyproj.network.is_network_enabled():
         return True
     available = [
         (
