@@ -19,8 +19,8 @@ from pyproj.enums import TransformDirection
 from pyproj.exceptions import ProjError
 from pyproj.transformer import AreaOfInterest, TransformerGroup
 from test.conftest import (
-    PROJ_GTE_81,
-    RGF93toWSG84,
+    PROJ_GTE_9,
+    PROJ_GTE_91,
     grids_available,
     proj_env,
     proj_network_env,
@@ -85,23 +85,6 @@ def test_lambert_conformal_transform():
     assert_almost_equal((Long1, Lat1, H1), (-4.6753456, 32.902199, 1341.467), decimal=5)
 
 
-def test_equivalent_crs():
-    with pytest.warns(DeprecationWarning):
-        Transformer.from_crs("epsg:4326", 4326, skip_equivalent=True)
-
-
-def test_equivalent_proj():
-    with pytest.warns(FutureWarning):
-        proj_from = pyproj.Proj("+init=epsg:4326")
-    with pytest.warns(DeprecationWarning):
-        Transformer.from_proj(proj_from, 4326, skip_equivalent=True)
-
-
-def test_equivalent_transformer_group():
-    with pytest.warns(DeprecationWarning):
-        TransformerGroup("epsg:4326", 4326, skip_equivalent=True)
-
-
 def test_4d_transform():
     transformer = Transformer.from_pipeline("+init=ITRF2008:ITRF2000")
     assert_almost_equal(
@@ -457,14 +440,6 @@ def test_str():
     assert str(Transformer.from_crs(4326, 3857)).startswith("proj=pipeline")
 
 
-if PROJ_GTE_81:
-    _BOUND_REPR = "(-16.1, 32.88, 40.18, 84.73)"
-else:
-    _BOUND_REPR = (
-        "(-16.096100515106, 32.884955146013, 40.178745269776, 84.722623821813)"
-    )
-
-
 @pytest.mark.parametrize(
     "from_crs, to_crs, expected_repr",
     [
@@ -486,7 +461,7 @@ else:
                 "Spain; Sweden; Switzerland; "
                 "United Kingdom (UK) including Channel Islands and Isle of Man; "
                 "Vatican City State.\n"
-                f"- bounds: {_BOUND_REPR}"
+                "- bounds: (-16.1, 32.88, 40.18, 84.73)"
             ),
         ),
         (
@@ -722,38 +697,34 @@ def test_transformer_group__get_transform_crs():
     tg = TransformerGroup("epsg:4258", "epsg:7415")
     if not grids_available("nl_nsgi_rdtrans2018.tif"):
         assert len(tg.transformers) == 1
-    else:
+    elif PROJ_GTE_91:
         assert len(tg.transformers) == 2
+    else:
+        assert len(tg.transformers) == 6
 
 
-@pytest.mark.grid
 def test_transformer__area_of_interest():
     transformer = Transformer.from_crs(
-        4326, 2964, area_of_interest=AreaOfInterest(-136.46, 49.0, -60.72, 83.17)
+        "EPSG:7789",
+        "EPSG:4936",
+        area_of_interest=AreaOfInterest(-177.25, -44.64, -43.3, -175.54),
+    )
+    assert (
+        transformer.description
+        == "Ballpark geocentric translation from ITRF2014 to ETRS89"
     )
-    if not grids_available("ca_nrc_ntv2_0.tif"):
-        assert (
-            transformer.description == "Inverse of NAD27 to WGS 84 (13) + Alaska Albers"
-        )
-    else:
-        assert (
-            transformer.description == "Inverse of NAD27 to WGS 84 (33) + Alaska Albers"
-        )
 
 
-@pytest.mark.grid
 def test_transformer_proj__area_of_interest():
     transformer = Transformer.from_proj(
-        4326, 2964, area_of_interest=AreaOfInterest(-136.46, 49.0, -60.72, 83.17)
+        "EPSG:7789",
+        "EPSG:4936",
+        area_of_interest=AreaOfInterest(-177.25, -44.64, -43.3, -175.54),
+    )
+    assert (
+        transformer.description
+        == "Ballpark geocentric translation from ITRF2014 to ETRS89"
     )
-    if not grids_available("ca_nrc_ntv2_0.tif"):
-        assert (
-            transformer.description == "Inverse of NAD27 to WGS 84 (13) + Alaska Albers"
-        )
-    else:
-        assert (
-            transformer.description == "Inverse of NAD27 to WGS 84 (33) + Alaska Albers"
-        )
 
 
 def test_transformer__area_of_interest__invalid():
@@ -1139,12 +1110,14 @@ def test_transformer_authority_filter():
     "input_string",
     [
         "EPSG:1671",
-        RGF93toWSG84,
+        "RGF93 v1 to WGS 84 (1)",
         "urn:ogc:def:coordinateOperation:EPSG::1671",
     ],
 )
 def test_transformer_from_pipeline__input_types(input_string):
-    assert Transformer.from_pipeline(input_string).description == RGF93toWSG84
+    assert (
+        Transformer.from_pipeline(input_string).description == "RGF93 v1 to WGS 84 (1)"
+    )
 
 
 @pytest.mark.parametrize(
@@ -1162,7 +1135,7 @@ def test_transformer_from_pipeline__wkt_json(method_name):
                 method_name,
             )()
         ).description
-        == RGF93toWSG84
+        == "RGF93 v1 to WGS 84 (1)"
     )
 
 
@@ -1550,3 +1523,101 @@ def test_pickle_transformer_from_crs():
         area_of_interest=AreaOfInterest(-136.46, 49.0, -60.72, 83.17),
     )
     assert transformer == pickle.loads(pickle.dumps(transformer))
+
+
+def test_unpickle_transformer_from_crs_v1_3():
+    pickled_transformer = (
+        b"\x80\x04\x95p\x01\x00\x00\x00\x00\x00\x00\x8c\x12"
+        b"pyproj.transformer\x94\x8c\x0bTransformer\x94\x93\x94)"
+        b"\x81\x94}\x94\x8c\x12_transformer_maker\x94h\x00\x8c\x12"
+        b"TransformerFromCRS\x94\x93\x94)\x81\x94}\x94(\x8c\x08"
+        b"crs_from\x94C\tEPSG:4326\x94\x8c\x06crs_to\x94C\tEPSG:2964"
+        b"\x94\x8c\talways_xy\x94\x88\x8c\x10area_of_interest\x94\x8c\n"
+        b"pyproj.aoi\x94\x8c\x0eAreaOfInterest\x94\x93\x94)\x81\x94}\x94"
+        b"(\x8c\x0fwest_lon_degree\x94G\xc0a\x0e\xb8Q\xeb\x85\x1f\x8c\x10"
+        b"south_lat_degree\x94G@H\x80\x00\x00\x00\x00\x00\x8c\x0f"
+        b"east_lon_degree\x94G\xc0N\\(\xf5\xc2\x8f\\\x8c\x10"
+        b"north_lat_degree\x94G@T\xca\xe1G\xae\x14"
+        b"{ub\x8c\tauthority\x94N\x8c\x08accuracy\x94N\x8c\x0eallow_ballpark\x94Nubsb."
+    )
+    transformer = Transformer.from_crs(
+        "EPSG:4326",
+        "EPSG:2964",
+        always_xy=True,
+        area_of_interest=AreaOfInterest(-136.46, 49.0, -60.72, 83.17),
+    )
+    assert transformer == pickle.loads(pickled_transformer)
+
+
+def test_transformer_group_accuracy_filter():
+    group = TransformerGroup("EPSG:4326", "EPSG:4258", accuracy=0.05)
+    assert not group.transformers
+    assert not group.unavailable_operations
+
+
+def test_transformer_group_allow_ballpark_filter():
+    group = TransformerGroup(
+        "EPSG:4326", "EPSG:4258", authority="PROJ", allow_ballpark=False
+    )
+    assert not group.transformers
+    assert not group.unavailable_operations
+
+
+def test_transformer_group_authority_filter():
+    group = TransformerGroup("EPSG:4326", "EPSG:4258", authority="PROJ")
+    assert len(group.transformers) == 1
+    assert not group.unavailable_operations
+    assert (
+        group.transformers[0].description
+        == "Ballpark geographic offset from WGS 84 to ETRS89"
+    )
+
+
+def test_transformer_force_over():
+    if PROJ_GTE_9:
+        transformer = Transformer.from_crs("EPSG:4326", "EPSG:3857", force_over=True)
+        # Test a point along the equator.
+        # The same point, but in two different representations.
+        xxx, yyy = transformer.transform(0, 140)
+        xxx_over, yyy_over = transformer.transform(0, -220)
+        # Web Mercator x's between 0 and 180 longitude come out positive.
+        # But when forcing the over flag, the -220 calculation makes it flip.
+        assert xxx > 0
+        assert xxx_over < 0
+        # check it works in both directions
+        xxx_inverse, yyy_inverse = transformer.transform(
+            xxx, yyy, direction=TransformDirection.INVERSE
+        )
+        xxx_over_inverse, yyy_over_inverse = transformer.transform(
+            xxx_over, yyy_over, direction=TransformDirection.INVERSE
+        )
+        assert_almost_equal(xxx_inverse, 0)
+        assert_almost_equal(xxx_over_inverse, 0)
+        assert_almost_equal(yyy_inverse, 140)
+        assert_almost_equal(yyy_over_inverse, -220)
+    else:
+        with pytest.raises(NotImplementedError, match="force_over requires PROJ 9"):
+            Transformer.from_crs("EPSG:4326", "EPSG:3857", force_over=True)
+
+
+def test_transformer__get_last_used_operation():
+    transformer = Transformer.from_crs("EPSG:4326", "EPSG:3857")
+    if PROJ_GTE_91:
+        with pytest.raises(
+            ProjError,
+            match=(
+                r"Last used operation not found\. "
+                r"This is likely due to not initiating a transform\."
+            ),
+        ):
+            transformer.get_last_used_operation()
+        xxx, yyy = transformer.transform(1, 2)
+        operation = transformer.get_last_used_operation()
+        assert isinstance(operation, Transformer)
+        assert xxx, yyy == operation.transform(1, 2)
+    else:
+        with pytest.raises(
+            NotImplementedError,
+            match=r"PROJ 9\.1\+ required to get last used operation\.",
+        ):
+            transformer.get_last_used_operation()
